@@ -125,7 +125,7 @@ netsnmp_register_mib_table_row(const char *moduleName,
         struct variable *vr =
             (struct variable *) ((char *) var + (i * varsize));
         netsnmp_handler_registration *r;
-        if ( var_subid > mibloclen ) {
+        if ( var_subid > (int)mibloclen ) {
             break;    /* doesn't make sense */
         }
         r = SNMP_MALLOC_TYPEDEF(netsnmp_handler_registration);
@@ -216,6 +216,7 @@ netsnmp_register_mib_table_row(const char *moduleName,
         reg_parms.range_subid = var_subid;
         reg_parms.range_ubound = ubound;
         reg_parms.timeout = timeout;
+        reg_parms.contextName = context;
         rc = snmp_call_callbacks(SNMP_CALLBACK_APPLICATION,
                                  SNMPD_CALLBACK_REGISTER_OID, &reg_parms);
     }
@@ -337,6 +338,7 @@ netsnmp_old_api_helper(netsnmp_mib_handler *handler,
                                                  SNMP_ERR_RESOURCEUNAVAILABLE);
             cacheptr->data = access;
             cacheptr->write_method = write_method;
+            write_method = NULL;
             netsnmp_request_add_list_data(requests,
                                           netsnmp_create_data_list
                                           (OLD_API_NAME, cacheptr, free));
