@@ -163,9 +163,10 @@ real_init_master(void)
              * diagnose snmp_open errors with the input netsnmp_session pointer 
              */
             if (!netsnmp_ds_get_boolean(NETSNMP_DS_APPLICATION_ID, NETSNMP_DS_AGENT_NO_ROOT_ACCESS)) {
-                snmp_sess_perror
-                    ("Error: Couldn't open a master agentx socket to listen on",
-                     &sess);
+                char buf[1024];
+                snprintf(buf, sizeof(buf),
+                    "Error: Couldn't open a master agentx socket to listen on (%s)", sess.peername);
+                snmp_sess_perror(buf, &sess);
                 exit(1);
             } else {
                 netsnmp_sess_log_error(LOG_WARNING,
@@ -399,7 +400,7 @@ agentx_got_response(int operation,
              * there is no way to fix the problem 
              */
             snmp_log(LOG_ERR,
-                     "response to agentx request illegal.  We're screwed.\n");
+                     "response to agentx request illegal.  bailing out.\n");
             netsnmp_set_request_error(cache->reqinfo, requests,
                                       SNMP_ERR_GENERR);
         }
@@ -503,6 +504,11 @@ agentx_master_handler(netsnmp_mib_handler *handler,
     pdu->reqid = snmp_get_next_transid();
     pdu->transid = reqinfo->asp->pdu->transid;
     pdu->sessid = ax_session->subsession->sessid;
+    if (reginfo->contextName) {
+        pdu->community = strdup(reginfo->contextName);
+        pdu->community_len = strlen(reginfo->contextName);
+        pdu->flags |= AGENTX_MSG_FLAG_NON_DEFAULT_CONTEXT;
+    }
     if (ax_session->subsession->flags & AGENTX_MSG_FLAG_NETWORK_BYTE_ORDER)
         pdu->flags |= AGENTX_MSG_FLAG_NETWORK_BYTE_ORDER;
 
