@@ -62,7 +62,7 @@
 #include <sys/var.h>
 #include <time.h>
 #include <unistd.h>
-#include <fcntl.h>
+#include <sys/fcntl.h>
 #include <sys/types.h>
 #include <sys/openpromio.h>
 #endif
@@ -93,10 +93,9 @@ struct utmp    *getutent(void);
 static struct openpromio * op_malloc(size_t size);
 static void op_free(struct openpromio *op);
 static int set_solaris_bootcommand_parameter(int action, u_char * var_val, u_char var_val_type, size_t var_val_len, u_char * statP, oid * name, size_t name_len);
-static int set_solaris_eeprom_parameter(const char *key, const char *value, size_t value_len);
-static int get_solaris_eeprom_parameter(const char *parameter, char *output);
+static int set_solaris_eeprom_parameter(char *key,char *value,size_t value_len);
+static int get_solaris_eeprom_parameter(char *parameter,char *output);
 static long     get_max_solaris_processes(void);
-static int set_solaris_time(int action, u_char * var_val, u_char var_val_type, size_t var_val_len, u_char * statP, oid * name, size_t name_len);
 #endif
 static int      get_load_dev(void);
 static int      count_users(void);
@@ -210,7 +209,7 @@ var_hrsys(struct variable * vp,
     char bootparam[8192];
 #endif
     time_t          now;
-#if !(defined(NR_TASKS) || defined(solaris2) || defined(hpux10) || defined(hpux11))
+#ifndef NR_TASKS
     int             nproc = 0;
 #endif
 #ifdef linux
@@ -233,8 +232,8 @@ var_hrsys(struct variable * vp,
         long_return = get_uptime();
         return (u_char *) & long_return;
     case HRSYS_DATE:
-#if defined(solaris2)
-        *write_method=set_solaris_time;
+#if defined(HAVE_MKTIME) && defined(HAVE_STIME)
+        *write_method=ns_set_time;
 #endif
         (void *) time(&now);
         return (u_char *) date_n_time(&now, var_len);
@@ -403,9 +402,7 @@ set_solaris_bootcommand_parameter(int action,
     return SNMP_ERR_NOERROR;
 }
 
-static int set_solaris_eeprom_parameter(const char *key, const char *value,
-					size_t var_val_len)
-{
+static int set_solaris_eeprom_parameter(char *key,char *value,size_t var_val_len) {
 
     int status=0;
     char buffer[1024],*pbuffer=buffer;
@@ -424,27 +421,25 @@ static int set_solaris_eeprom_parameter(const char *key, const char *value,
     if(pbuffer!=buffer) free(pbuffer);
     return status;
 }
-
-static int get_solaris_eeprom_parameter(const char *parameter, char *outbuffer)
-{
+static int get_solaris_eeprom_parameter(char *parameter,char *outbuffer) {
 
     int fd=0,status=0;
     struct openpromio *openprominfo=NULL;
 
     fd=open("/dev/openprom",O_RDONLY);
     if ( fd == -1 ) {
-        snmp_log_perror("/dev/openprom");
+        snmp_log(LOG_ERR,"cannot open /dev/openprom\n");
         return 1;
     }
 
-    openprominfo = op_malloc(8192);
+    openprominfo=(struct openpromio *)op_malloc(8192);
     if(!openprominfo) return 1;
 
     strcpy(openprominfo->oprom_array,parameter);
 
     status=ioctl(fd,OPROMGETOPT,openprominfo);
     if ( status == -1 ) {
-        snmp_log_perror("/dev/openprom");
+        snmp_log(LOG_ERR,"cannot read from /dev/openprom\n");
         close(fd);
         op_free(openprominfo);
         return 1;
@@ -458,7 +453,6 @@ static int get_solaris_eeprom_parameter(const char *parameter, char *outbuffer)
 
     return(0);
 }
-
 static long get_max_solaris_processes(void) {
 
     kstat_ctl_t *ksc=NULL;
@@ -482,8 +476,11 @@ static long get_max_solaris_processes(void) {
     return maxprocs;
 }
 
-static int
-set_solaris_time(int action,
+#endif
+
+#if defined(HAVE_MKTIME) && defined(HAVE_STIME)
+int
+ns_set_time(int action,
             u_char * var_val,
             u_char var_val_type,
             size_t var_val_len,
@@ -496,9 +493,13 @@ set_solaris_time(int action,
         case RESERVE1:
             /* check type */
             if (var_val_type != ASN_OCTET_STR) {
-                snmp_log(LOG_ERR,"write to set_solaris_time not ASN_OCTET_STR\n");
+                snmp_log(LOG_ERR,"write to ns_set_time not ASN_OCTET_STR\n");
                 return SNMP_ERR_WRONGTYPE;
             }
+            if (var_val_len != 8 && var_val_len!=11) {
+                snmp_log(LOG_ERR,"write to ns_set_time not a proper length\n");
+                return SNMP_ERR_WRONGVALUE;
+            }
             break;
 
         case RESERVE2:
@@ -511,8 +512,14 @@ set_solaris_time(int action,
             long status=0;
             time_t seconds=0;
             struct tm newtimetm;
-            int hours_from_utc=(int)var_val[9];
-            int minutes_from_utc=(int)var_val[10];
+            int hours_from_utc= 0;
+            int minutes_from_utc= 0;
+
+            if (var_val_len == 11) {
+                /* timezone inforamation was present */
+                hours_from_utc=(int)var_val[9];
+                minutes_from_utc=(int)var_val[10];
+            }
 
             newtimetm.tm_sec=(int)var_val[6];;
             newtimetm.tm_min=(int)var_val[5];
