@@ -236,7 +236,8 @@ ip_handler(netsnmp_mib_handler          *handler,
      * But just to be safe, check this and load it manually if necessary
      */
 #ifndef hpux11
-    if (!netsnmp_is_cache_valid(reqinfo)) {
+    if (!netsnmp_cache_is_valid(reqinfo, reginfo->handlerName)) {
+        netsnmp_assert("cache" == "valid"); /* always false */
         ip_load( NULL, NULL );	/* XXX - check for failure */
     }
 #endif
@@ -406,7 +407,7 @@ ip_handler(netsnmp_mib_handler          *handler,
          * ipstat.ips_noroute is also incorrect.
          */
         netsnmp_set_request_error(reqinfo, request, SNMP_NOSUCHOBJECT);
-        return NULL;
+        continue;
     case IPREASMTIMEOUT:
         ret_value = IPFRAGTTL;
         type = ASN_INTEGER;
