@@ -6,6 +6,7 @@ config_require(ucd-snmp/pass_persist)
 config_require(ucd-snmp/disk)
 config_require(ucd-snmp/loadave)
 config_require(ucd-snmp/extensible)
+config_require(agent/extend)
 config_require(ucd-snmp/errormib)
 config_require(ucd-snmp/file)
 config_require(ucd-snmp/dlmod)
@@ -40,10 +41,6 @@ config_arch_require(freebsd5, ucd-snmp/vmstat_freebsd2)
 config_arch_require(freebsd5, ucd-snmp/memory_freebsd2)
 config_arch_require(netbsd1, ucd-snmp/vmstat_netbsd1)
 config_arch_require(netbsd1, ucd-snmp/memory_netbsd1)
-config_arch_require(netbsd, ucd-snmp/vmstat_netbsd1)
-config_arch_require(netbsd, ucd-snmp/memory_netbsd1)
-config_arch_require(netbsdelf, ucd-snmp/vmstat_netbsd1)
-config_arch_require(netbsdelf, ucd-snmp/memory_netbsd1)
 config_arch_require(openbsd2, ucd-snmp/vmstat_netbsd1)
 config_arch_require(openbsd2, ucd-snmp/memory_netbsd1)
 config_arch_require(bsdi4, ucd-snmp/vmstat_bsdi4)
