@@ -9,6 +9,7 @@ extern          "C" {
 #include <net-snmp/agent/baby_steps.h>
 #include <net-snmp/agent/scalar.h>
 #include <net-snmp/agent/scalar_group.h>
+#include <net-snmp/agent/watcher.h>
 #include <net-snmp/agent/multiplexer.h>
 #include <net-snmp/agent/null.h>
 #include <net-snmp/agent/debug_handler.h>
@@ -26,10 +27,14 @@ extern          "C" {
 #include <net-snmp/agent/table_data.h>
 #include <net-snmp/agent/table_dataset.h>
 #include <net-snmp/agent/table_iterator.h>
+#include <net-snmp/agent/table_container.h>
 /*
  * #include <net-snmp/agent/table_array.h> 
  */
 
+#include <net-snmp/agent/mfd.h>
+
+
 void            netsnmp_init_helpers(void);
 
 #ifdef __cplusplus
