@@ -65,7 +65,7 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK @EXPORT $VERSION $AUTOLOAD);
 	ASN_UNSIGNED
 	ASN_UNSIGNED64
 );
-$VERSION = '5.1.3';
+$VERSION = '5.2.1';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -109,16 +109,20 @@ __END__
 
 =head1 NAME
 
-NetSNMP::ASN - Perl extension for SNMP ASN.1 types
+NetSNMP::ASN - Perl extension for blah blah blah
 
 =head1 SYNOPSIS
 
-  use NetSNMP::ASN qw(':all');
-  my $asn_int = ASN_INTEGER;
+  use NetSNMP::ASN;
+  blah blah blah
 
 =head1 DESCRIPTION
 
-The NetSNMP::ASN module provides the ASN.1 types for SNMP.
+Stub documentation for NetSNMP::ASN, created by h2xs. It looks like the
+author of the extension was negligent enough to leave the stub
+unedited.
+
+Blah blah blah.
 
 =head2 EXPORT
 
@@ -150,12 +154,10 @@ None by default.
 
 =head1 AUTHOR
 
-Wes Hardaker, E<lt>hardaker@users.sourceforge.netE<gt>
+A. U. Thor, a.u.thor@a.galaxy.far.far.away
 
 =head1 SEE ALSO
 
-SNMP(3pm), NetSNMP::OID(3pm)
-
 perl(1).
 
 =cut
